@@ -16,7 +16,7 @@
  *  Copyright (C) 2000 - 2005 Liam Girdwood  
  */
 
-#define LIBNOVA_VERSION "0.12.2"
+#define LIBNOVA_VERSION "0.13.0"
 
 /*! \mainpage libnova
 * \image html libnova-logo.jpg
@@ -53,12 +53,13 @@
 * - Semidiameters of the Sun, Moon, Planets and asteroids.
 * - Angular separation of bodies
 * - Hyperbolic motion of bodies
+* - Heliocentric (barycentric) time correction
 *
 * \section docs Documentation
 * API documentation for libnova is included in the source. It can also be found in this website and an offline tarball is available <A href="http://libnova.sf.net/libnovadocs.tar.gz">here</A>.
 *
 * \section download Download
-* The latest released version of libnova is 0.12.2.
+* The latest released version of libnova is 0.13.0
 * It is available for download <A href="http://sf.net/project/showfiles.php?group_id=57697">here.</A>
 *
 * \section cvs CVS
@@ -131,5 +132,6 @@
 #include <libnova/hyperbolic_motion.h>
 #include <libnova/parallax.h>
 #include <libnova/airmass.h>
+#include <libnova/heliocentric_time.h>
 
 #endif
